@@ -14,6 +14,9 @@ parser = argparse.ArgumentParser(description='Manage daemonized (g)unicorns.')
 parser.add_argument('-u', '--unicorn', default='gunicorn', metavar='TYPE',
                     choices=['unicorn', 'gunicorn','gunicorn_django'],
                     help='The type of unicorn to manage (gunicorn, gunicorn_django, unicorn)')
+parser.add_argument('-b', '--unicorn-bin', default=None, metavar='UNICORN_BIN',
+                    type=str, dest='unicorn_bin',
+                    help='path to a specific unicorn to manage')
 parser.add_argument('-p', '--pidfile', metavar='PATH',
                     help='Path to the pidfile that unicorn will write')
 parser.add_argument('-t', '--timeout', default=30, type=int, metavar='30', dest='boot_timeout',
